@@ -23,6 +23,9 @@ pub struct LogWriterConfig {
     /// The maximum amount of space that is allowed to be used,
     /// relative to the total space (0.01 = 1%)
     pub max_use_of_total: Option<f64>,
+    /// The maximum amount of space that is allowed to be used,
+    /// in bytes
+    pub max_use_bytes: Option<u64>,
     /// The minimum amount of space that should be kept available at all times,
     /// relative to the total space (0.01 = 1%)
     pub min_avail_of_total: Option<f64>,
@@ -33,6 +36,11 @@ pub struct LogWriterConfig {
     pub max_file_size: usize,
     /// Rotated after X seconds, regardless of size
     pub max_file_age: Option<u64>,
+    /// Disk space subtracted when checking if max_use_of_total is reached.
+    /// Set this to the absolute amount of space you expect other services to take up on the
+    /// partition.
+    /// in bytes
+    pub reserved: Option<usize>,
 }
 
 /// Writes a stream to disk while adhering to the usage limits described in `cfg`.
@@ -95,8 +103,22 @@ impl<T: LogWriterCallbacks + Sized + Clone + Debug> LogWriter<T> {
     fn enough_space(&mut self, len: usize) -> Result<bool> {
         let fsstat = fsstats::statvfs(&self.cfg.target_dir)?;
 
+        let mut size_limit = u64::MAX;
+
+        if let Some(max_use_bytes) = self.cfg.max_use_bytes {
+            size_limit = std::cmp::min(size_limit, max_use_bytes);
+        }
+
         if let Some(max_use_of_total) = self.cfg.max_use_of_total {
-            let mut used = 0;
+            let mut max_use_bytes = (max_use_of_total * fsstat.total_space as f64) as u64;
+            if let Some(reserved) = self.cfg.reserved {
+                max_use_bytes -= reserved as u64;
+            };
+            size_limit = std::cmp::min(size_limit, max_use_bytes);
+        }
+
+        if size_limit != u64::MAX {
+            let mut used = 0u64;
             for entry in fs::read_dir(&self.cfg.target_dir)? {
                 let entry = match entry {
                     Err(_) => {
@@ -122,8 +144,7 @@ impl<T: LogWriterCallbacks + Sized + Clone + Debug> LogWriter<T> {
 
                 used += meta.blocks() * 512;
             };
-            let used_of_total = used as f64 / fsstat.total_space as f64;
-            if used_of_total > max_use_of_total {
+            if used > size_limit {
                 return Ok(false);
             }
         }
